Quick class

Constructors

Quick()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toast({required BuildContext context, String message = "Hello from quick_widgets 🚀", Color backgroundColor = Colors.black87, int durationInSeconds = 2, ToastType toastType = ToastType.flat, double radius = 20, TextStyle textStyle = const TextStyle(color: Colors.white), SnackBarBehavior behavior = SnackBarBehavior.floating, bool showCloseIcon = false, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, double? width, double elevation = 6.0, String closeBtnLabel = "Hide", Function? onCloseBtnTap, BorderSide? border}) Future<void>
Show Toast message