onCaptured property
Callback function that gets called when an image or video is captured Parameters: type (String) - either 'image' or 'video', file (File) - the captured file
Implementation
final Function(String type, File file)? onCaptured;
Callback function that gets called when an image or video is captured Parameters: type (String) - either 'image' or 'video', file (File) - the captured file
final Function(String type, File file)? onCaptured;